==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/outputs/GetImportPipelineResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * An object that represents an import pipeline for a container registry.
 * @property id The resource ID.
 * @property identity The identity of the import pipeline.
 * @property location The location of the import pipeline.
 * @property name The name of the resource.
 * @property options The list of all options configured for the pipeline.
 * @property provisioningState The provisioning state of the pipeline at the time the operation was called.
 * @property source The source properties of the import pipeline.
 * @property systemData Metadata pertaining to creation and last modification of the resource.
 * @property trigger The properties that describe the trigger of the import pipeline.
 * @property type The type of the resource.
 */
public data class GetImportPipelineResult(
    public val id: String,
    public val identity: IdentityPropertiesResponse? = null,
    public val location: String? = null,
    public val name: String,
    public val options: List<String>? = null,
    public val provisioningState: String,
    public val source: ImportPipelineSourcePropertiesResponse,
    public val systemData: SystemDataResponse,
    public val trigger: PipelineTriggerPropertiesResponse? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.containerregistry.outputs.GetImportPipelineResult):
            GetImportPipelineResult = GetImportPipelineResult(
            id = javaType.id(),
            identity = javaType.identity().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.containerregistry.kotlin.outputs.IdentityPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            options = javaType.options().map({ args0 -> args0 }),
            provisioningState = javaType.provisioningState(),
            source = javaType.source().let({ args0 ->
                com.pulumi.azurenative.containerregistry.kotlin.outputs.ImportPipelineSourcePropertiesResponse.Companion.toKotlin(args0)
            }),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.containerregistry.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            trigger = javaType.trigger().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.containerregistry.kotlin.outputs.PipelineTriggerPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/outputs/GetImportPipelineResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * An object that represents an import pipeline for a container registry.
 * @property id The resource ID.
 * @property identity The identity of the import pipeline.
 * @property location The location of the import pipeline.
 * @property name The name of the resource.
 * @property options The list of all options configured for the pipeline.
 * @property provisioningState The provisioning state of the pipeline at the time the operation was called.
 * @property source The source properties of the import pipeline.
 * @property systemData Metadata pertaining to creation and last modification of the resource.
 * @property trigger The properties that describe the trigger of the import pipeline.
 * @property type The type of the resource.
 */
public data class GetImportPipelineResult(
    public val id: String,
    public val identity: IdentityPropertiesResponse? = null,
    public val location: String? = null,
    public val name: String,
    public val options: List<String>? = null,
    public val provisioningState: String,
    public val source: ImportPipelineSourcePropertiesResponse,
    public val systemData: SystemDataResponse,
    public val trigger: PipelineTriggerPropertiesResponse? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.containerregistry.outputs.GetImportPipelineResult): GetImportPipelineResult = GetImportPipelineResult(
            id = javaType.id(),
            identity = javaType.identity().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.containerregistry.kotlin.outputs.IdentityPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            options = javaType.options().map({ args0 -> args0 }),
            provisioningState = javaType.provisioningState(),
            source = javaType.source().let({ args0 ->
                com.pulumi.azurenative.containerregistry.kotlin.outputs.ImportPipelineSourcePropertiesResponse.Companion.toKotlin(args0)
            }),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.containerregistry.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            trigger = javaType.trigger().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.containerregistry.kotlin.outputs.PipelineTriggerPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            type = javaType.type(),
        )
    }
}
